@@ -372,7 +372,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
 
     @property
     @decorators.synchronized
-    def threadpool(self):
+    def concurrent_pool(self):
         return self._concurrent_mode_dispatcher.build_pool()
 
     def custom_init(self):
@@ -476,7 +476,8 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
 
             except Exception as e:
                 if isinstance(e, (PyMongoError, ExceptionForRequeue)):  # mongo经常维护备份时候插入不了或挂了，或者自己主动抛出一个ExceptionForRequeue类型的错误会重新入队，不受指定重试次数逇约束。
-                    self.logger.critical(f'函数 [{self.consuming_function.__name__}] 中发生错误 {type(e)}  {e}')
+                    self.logger.critical(f'函数 [{self.consuming_function.__name__}] 中发生错误 {type(e)}  {e}，消息重新入队')
+                    time.sleep(1)  # 防止快速无限出错入队出队，导致cpu和中间件忙
                     return self._requeue(kw)
                 self.logger.error(f'函数 {self.consuming_function.__name__}  第{current_retry_times + 1}次发生错误，'
                                   f'函数运行时间是 {round(time.time() - t_start, 4)} 秒,\n  入参是 【 {function_only_params} 】   \n 原因是 {type(e)} {e} ', exc_info=self.__get_priority_conf(kw, 'is_print_detail_exception'))
@@ -488,8 +489,12 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         self._result_persistence_helper.save_function_result_to_mongo(function_result_status)
         if self.__get_priority_conf(kw, 'is_using_rpc_mode'):
             # print(function_result_status.get_status_dict(without_datetime_obj=True))
-            RedisMixin().redis_db_frame.lpush(kw['body']['extra']['task_id'], json.dumps(function_result_status.get_status_dict(without_datetime_obj=True)))
-            RedisMixin().redis_db_frame.expire(kw['body']['extra']['task_id'], 600)
+            with RedisMixin().redis_db_frame.pipeline() as p:
+                # RedisMixin().redis_db_frame.lpush(kw['body']['extra']['task_id'], json.dumps(function_result_status.get_status_dict(without_datetime_obj=True)))
+                # RedisMixin().redis_db_frame.expire(kw['body']['extra']['task_id'], 600)
+                p.lpush(kw['body']['extra']['task_id'], json.dumps(function_result_status.get_status_dict(without_datetime_obj=True)))
+                p.expire(kw['body']['extra']['task_id'], 600)
+                p.execute()
 
     @abc.abstractmethod
     def _confirm_consume(self, kw):
@@ -522,7 +527,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
                                 f'超过了指定的 {msg_expire_senconds_priority} 秒，丢弃任务')
             self._confirm_consume(kw)
             return 0
-        self.threadpool.submit(self._run, kw)
+        self.concurrent_pool.submit(self._run, kw)
         time.sleep(self._msg_schedule_time_intercal)
 
     @decorators.FunctionResultCacher.cached_function_result_for_a_time(120)
