@@ -4,13 +4,13 @@
 import json
 from threading import Lock
 
-from pika.exceptions import AMQPError
+from pikav0.exceptions import AMQPError
 
 from function_scheduling_distributed_framework.consumers.base_consumer import AbstractConsumer
 from function_scheduling_distributed_framework.utils import LogManager
 from function_scheduling_distributed_framework.utils.rabbitmq_factory import RabbitMqFactory
 
-LogManager('pika').get_logger_and_add_handlers(20)
+LogManager('pikav0').get_logger_and_add_handlers(20)
 
 
 class RabbitmqConsumer(AbstractConsumer):
